% MtGetValue returns the value of an attribute. 
%
%   [status, ...] = ...
%                 MtGetValue (object,attribute, ...); % see EOF for all combinations
%   [status, type, rank, typesize, default] = ...
%                 MtGetValue (object, attribute, 1, 0, 1, 1, 1);
%   [status, type, value, rank, typesize, default] = ...
%                 MtGetValue (object, attribute, type, 1, 1, typesize, 1);
%
%   This function returns the value of an attribute for the object specified as 
%   an argument. The value corresponds to the attribute default value when the 
%   attribute has no value in the object. In this case, default is set to MT_TRUE (1).
%
%   The function can also be called to retrieve information about this specific 
%   value, instead of the value itself. This is for instance convenient for 
%   attribute that can have values of multiple types.
%
%   The name of the attributes is not case sensitive. These functions can be called 
%   either inside a transaction or during a version access.
%
%   If the attribute has not been assigned for the object and if the attribute has 
%   no default value, MATISSE gives the default value of the attribute default value, 
%   which has the type MT_NIL.
%
%   OUTPUT [1,2,3,4,5 or 6]
%
%      status: 1xn array of char
%          The status indicates if the statement was successful evaluated,
%          otherwise a string other than 'MATISSE_SUCCESS' is returned.
%    
%      type: number (optional)
%          The type of the attribute. When the third input argument is set to NULL, 
%          the function does not return the type. Currently implemented:
%             MT_FLOAT
%             MT_DOUBLE
%             MT_TIMESTAMP
%             MT_SHORT
%             MT_INTEGER
%             MT_LONG    
%             MT_OID
%             MT_CHAR
%             MT_NULL
%             MT_STRING
%
%      value: number (optional)
%          The value to be retrieved. When the fourth input argument is set
%          to NULL, the function does not return the value. 
%          This may prove useful, especially when the user is interested in the type, 
%          the dimension of the attribute value, or the size of this property.        
%
%      rank: number (optional)
%          The number of dimensions of the value. When the fifth input argument is  
%          set to NULL, the function does not return the information. 
%
%          The number of dimensions of a value is equal to 1 for the MT_*_LIST types 
%          when the stored value is not NULL, equal to 0 otherwise. It can range from 
%          1 to 8 for the MT_*_ARRAY types when the stored value is not NULL, equal to 
%          0 otherwise. For all other types the rank is always 0.
%
%      typesize: number (optional)
%          The size of the buffer for the value that is returned. When the stored 
%          value is NULL, then size is equal to 0.  When the sixth input argument   
%          is set to NULL, the function does not return the typesize. 
%
%      default: number (optional)
%          indicates if the value of the object is ever explicitly set, or that the
%          object still contains the default value from the schema. Default is set to 
%          MT_TRUE (1) when the attribute has no value in the object, i.e., when the 
%          value that is returned corresponds to the attribute default value. 
%
%          Default is set to MT_FALSE (0) when the attribute has a value. 
%          When the seventh input argument is set to NULL, the function does not 
%          return the default flag. 
%
%   INPUT [7]
%
%      object: number
%          The key to an object. 
%
%      attribute: number or string
%           A key to an attribute or an attribute name.
%
%      type: number or string
%          Two meanings:
%          - flag to indicate that no type information is needed (when NULL)
%          - the actual type of the value to be retrieved (when not NULL)
%
%      value: number
%          a flag to indicate if the value has to be retrieved. 
%
%      rank: number
%          a flag to indicate that no rank information is needed (when NULL) 
%
%      typesize: number 
%          Two meanings:
%          - flag to indicate that no sizee information is needed (when NULL)
%          - the actual size of the value to be retrieved (when not NULL)
%
%      default: number
%          a flag to indicate that no default information is needed (when NULL)
%
%   Example:
%
%   nbObjects = 1;
%
%   [status, conn] = MtAllocateConnection;
%   status = MtConnectDatabase (conn, 'amelie.wins.uva.nl', 'Video501');
%   status = MtSetCurrentConnection (conn);
%   status = MtStartVersionAccess;
%   [status, stream] = MtOpenInstancesStream('Movie', nbObjects);
%
%   i = 1; 
%   [status, object(i)] = MtNextObject (stream);
%
%   while i <= nbObjects & strcmp (status, 'MATISSE_SUCCESS');
%
%      [status] = ...
%               	MtGetValue (object(i),'Name', 0, 0, 0, 0, 0); 
%      [status, type] = ...
%               	MtGetValue (object(i),'Title' , 1, 0, 0, 0, 0); 
%      [status, rank] = ...
%               	MtGetValue (object(i),'Thumbnail', 0, 0, 1, 0, 0);
%      [status, typesize] = ...
%               	MtGetValue (object(i),'Rating', 0, 0, 0, 1, 0);
%      [status, default] = ...
%               	MtGetValue (object(i),'Preview', 0, 0, 0, 0, 1);
% %
% % Many different combinations of output arguments are possible.
% % Yet, to request a value without specifying the correct type is impossible.
% % Read MtGetValue.m itself for to find all possible combinations. 
% % Here only some often used combinations.
% %
%      [status, type, typesize] = ...
%                 MtGetValue (object(i),'Category', 1, 0, 0, 1, 0);
%      [status, type, value, typesize] = ...
%                 MtGetValue (object(i),'Category', type, 1, 0, typesize, 0);
%
%      [status, type, typesize, default] = ...
%                 MtGetValue (object(i), 'Synopsis', 1, 0, 0, 1, 1);
%      [status, type, value, typesize, default] = ...
%                 MtGetValue (object(i), 'Synopsis', type, 1, 0, typesize, 1);
%
%      [status, type, rank, typesize, default] = ...
%                 MtGetValue (object(i), 'RunningTime', 1, 0, 1, 1, 1);
%      [status, type, value, rank, typesize, default] = ...
%                 MtGetValue (object(i), 'RunningTime', type, 1, 1, typesize, 1);
%
%      i = i + 1;
%      [status, object(i)] = MtNextObject (stream);
%   end
%   status = MtCloseStream (stream);
%   status = MtEndVersionAccess;
%   status = MtNoCurrentConnection;
%   status = MtDisconnectDatabase (conn);
%   status = MtFreeConnection (conn);
%
%   See also: 
%      MtGetDimension
%      MtGetListElements

% All possible ways to call the function:
%
%   [status] = ...
%               	MtGetValue (object,attribute, 0, 0, 0, 0, 0);
%   [status, type] = ...
%               	MtGetValue (object,attribute, 1, 0, 0, 0, 0);
%   [status, rank] = ...
%               	MtGetValue (object,attribute, 0, 0, 1, 0, 0);
%   [status, typesize] = ...
%               	MtGetValue (object,attribute, 0, 0, 0, 1, 0);
%   [status, default] = ...
%               	MtGetValue (object,attribute, 0, 0, 0, 0, 1);
%   [status, type, rank] = ...
%               	MtGetValue (object,attribute, 1, 0, 1, 0, 0);
%   [status, type, typesize] = ...
%               	MtGetValue (object,attribute, 1, 0, 0, 1, 0);
%   [status, type, default] = ...
%               	MtGetValue (object,attribute, 1, 0, 0, 0, 1);
%   [status, rank, typesize] = ...
%               	MtGetValue (object,attribute, 0, 0, 1, 1, 0);
%   [status, rank, default] = ...
%               	MtGetValue (object,attribute, 0, 0, 1, 0, 1);
%   [status, typesize, default] = ...
%               	MtGetValue (object,attribute, 0, 0, 0, 1, 1);
%   [status, type, value, typesize] = ...
%                 MtGetValue (object, attribute, type, 1, 0, typesize, 0);
%   [status, type, rank, typesize] = ...
%                 MtGetValue (object, attribute, 1, 0, 1, 1, 0);
%   [status, type, rank, default] = ...
%                 MtGetValue (object, attribute, 1, 0, 1, 0, 1);
%   [status, type, typesize, default] = ...
%                 MtGetValue (object, attribute, 1, 0, 0, 1, 1);
%   [status, type, value, rank, typesize] = ...
%                 MtGetValue (object, attribute, type, 1, 1, typesize, 0);
%   [status, type, value, typesize, default] = ...
%                 MtGetValue (object, attribute, type, 1, 0, typesize, 1);
%   [status, type, rank, typesize, default] = ...
%                 MtGetValue (object, attribute, 1, 0, 1, 1, 1);
%   [status, type, value, rank, typesize, default] = ...
%                 MtGetValue (object, attribute, type, 1, 1, typesize, 1);

%   This function is part of the Matlab - Matisse interface
%   Version: Matlab 6.0.0.88 (R12) - Matisse 5.0.1
%   Author:  Arnoud Visser <arnoud@science.uva.nl>
%   Date:    December 2001

